@@ -6,7 +6,7 @@ use 5.020;
 use stable 0.031 'postderef';
 use experimental 'signatures';
 use feature 'state';
-use JSON::MaybeXS 1.002004 'is_bool';
+use builtin::compat 'blessed';
 
 sub new {
   return bless {}, __PACKAGE__;
@@ -30,4 +30,19 @@ sub validate_json_string ($self, $data_string, $schema) {
   return $self->validate_data($decoder->decode($data_string), $schema);
 }
 
+# lifted from JSON::Schema::Modern::Utilities, which lifted it from JSON::MaybeXS
+# note: unlike builtin::compat::is_bool on older perls, we do not accept
+# dualvar(0,"") or dualvar(1,"1") because JSON::PP and Cpanel::JSON::XS
+# do not encode these as booleans.
+use constant HAVE_BUILTIN => "$]" >= 5.035010;
+use if HAVE_BUILTIN, experimental => 'builtin';
+sub is_bool ($value) {
+  HAVE_BUILTIN and builtin::is_bool($value)
+  or
+  !!blessed($value)
+    and ($value->isa('JSON::PP::Boolean')
+      or $value->isa('Cpanel::JSON::XS::Boolean')
+      or $value->isa('JSON::XS::Boolean'));
+}
+
 1;
